# RentcastRentalListingsLongTerm200ResponseInnerHistory20240918


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**event** | **str** |  | [optional] 
**price** | **float** |  | [optional] [default to ]
**listing_type** | **str** |  | [optional] 
**listed_date** | **datetime** |  | [optional] 
**removed_date** | **datetime** |  | [optional] 
**days_on_market** | **float** |  | [optional] [default to ]

## Example

```python
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_history20240918 import RentcastRentalListingsLongTerm200ResponseInnerHistory20240918

# TODO update the JSON string below
json = "{}"
# create an instance of RentcastRentalListingsLongTerm200ResponseInnerHistory20240918 from a JSON string
rentcast_rental_listings_long_term200_response_inner_history20240918_instance = RentcastRentalListingsLongTerm200ResponseInnerHistory20240918.from_json(json)
# print the JSON string representation of the object
print(RentcastRentalListingsLongTerm200ResponseInnerHistory20240918.to_json())

# convert the object into a dict
rentcast_rental_listings_long_term200_response_inner_history20240918_dict = rentcast_rental_listings_long_term200_response_inner_history20240918_instance.to_dict()
# create an instance of RentcastRentalListingsLongTerm200ResponseInnerHistory20240918 from a dict
rentcast_rental_listings_long_term200_response_inner_history20240918_from_dict = RentcastRentalListingsLongTerm200ResponseInnerHistory20240918.from_dict(rentcast_rental_listings_long_term200_response_inner_history20240918_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


